# CountDown - 纪念日倒计时应用

一个基于 Tauri + React + TypeScript 构建的跨平台纪念日倒计时应用，支持桌面端和移动端。

## ✨ 特性

- 📅 添加和管理重要纪念日
- ⏰ 实时计算从纪念日开始到现在的天数
- 🎨 8种精美主题，每次启动随机切换
- 📱 响应式设计，支持桌面和移动端
- 🗃️ 本地SQLite数据库存储
- ⚡ 基于Tauri的原生性能

## 🎨 主题系统

应用内置8种不同风格的主题：
- 🔵 蓝色主题（默认）
- 🟢 绿色主题
- 🟣 紫色主题
- 🟠 橙色主题
- 🩷 粉色主题
- 🔷 青色主题
- ⚫ 暗色主题
- 🌈 渐变主题

每次启动应用会随机选择一个主题，为用户带来不同的视觉体验。

## 🚀 快速开始

### 环境要求
- Node.js 18+
- Rust 1.70+
- pnpm

### 安装依赖
```bash
pnpm install
```

### 开发模式
```bash
pnpm tauri dev
```

### 构建应用
```bash
# 桌面端
pnpm tauri build

# 或使用脚本
./build_desktop.sh

# Android端
./build_android.sh
```

## 🏗️ 技术架构

### 前端
- **框架**: React 18 + TypeScript
- **路由**: React Router DOM
- **构建**: Vite
- **样式**: CSS Variables + 响应式设计

### 后端
- **框架**: Tauri 2.x + Rust
- **数据库**: SQLite (rusqlite)
- **数据序列化**: Serde
- **日期处理**: Chrono

### 数据库结构
```sql
CREATE TABLE anniversaries (
    id INTEGER PRIMARY KEY AUTOINCREMENT,
    title TEXT NOT NULL,
    start_date TEXT NOT NULL,
    created_at DATETIME DEFAULT CURRENT_TIMESTAMP
);
```

## 📱 功能页面

应用包含三个主要页面：
- **首页**: 显示所有纪念日列表和天数统计
- **详情页**: 查看单个纪念日详情和删除操作
- **添加页**: 创建新的纪念日记录

## 📄 许可证

本项目使用 [MIT License](LICENSE) 开源协议。
