import { useState } from "react";
import { useNavigate } from "react-router-dom";
import { invoke } from "@tauri-apps/api/core";
import "./AddPage.css";

function AddPage() {
  const navigate = useNavigate();
  const [title, setTitle] = useState("");
  const [date, setDate] = useState("");

  const handleSubmit = async () => {
    try {
      await invoke("add_anniversary", {
        title,
        startDate: date,
      });
      // 添加成功后返回主页
      navigate("/");
    } catch (error) {
      console.error("Failed to add anniversary:", error);
    }
  };

  return (
    <div className="container">
      <div className="nav-bar">
        <button className="back-button" onClick={() => navigate("/")}>
          <span className="back-icon">←</span>
          <span>Back</span>
        </button>
        <h1 className="page-title">Add New</h1>
      </div>
      <div className="form-card">
        <div className="form-group">
          <label>Title</label>
          <input
            type="text"
            value={title}
            onChange={(e) => setTitle(e.target.value)}
            placeholder="Enter anniversary title"
          />
        </div>
        <div className="form-group">
          <label>Start Date</label>
          <input
            type="date"
            value={date}
            onChange={(e) => setDate(e.target.value)}
          />
        </div>
        <button className="submit-button" onClick={handleSubmit}>
          Create Anniversary
        </button>
      </div>
    </div>
  );
}

export default AddPage;
