import { useState, useEffect } from "react";
import { useParams, useNavigate } from "react-router-dom";
import { invoke } from "@tauri-apps/api/core";
import "./DetailPage.css";

interface Anniversary {
  id: number;
  title: string;
  start_date: string;
  days: number;
}

function DetailPage() {
  const { id } = useParams(); // 获取路由参数
  const navigate = useNavigate(); // 获取导航函数
  const [anniversary, setAnniversary] = useState<Anniversary>({
    id: 0,
    title: "",
    start_date: "",
    days: 0,
  });

  useEffect(() => {
    const getAnniversaryData = async () => {
      if (id) {
        const result = await invoke<Anniversary>("get_anniversary_by_id", {
          id: parseInt(id),
        });
        setAnniversary(result);
      }
    };
    getAnniversaryData();
  }, [id]);

  const handleDelete = async () => {
    if (id) {
      try {
        await invoke("delete_anniversary", { id: parseInt(id) });
        navigate("/"); // 删除成功后返回主页
      } catch (error) {
        console.error("Failed to delete anniversary:", error);
      }
    }
  };

  return (
    <div className="container">
      <div className="nav-bar">
        <button className="back-button" onClick={() => navigate("/")}>
          <span className="back-icon">←</span>
          <span>Back</span>
        </button>
        <button className="delete-button" onClick={handleDelete}>
          Delete
        </button>
      </div>
      <div className="card">
        <h1 className="title">{anniversary.title}</h1>
        <div className="days">{anniversary.days}</div>
        <div className="start-date">Start Date: {anniversary.start_date}</div>
      </div>
    </div>
  );
}

export default DetailPage;
