import { useState, useEffect } from "react";
import { invoke } from "@tauri-apps/api/core";
import { useNavigate } from "react-router-dom";
import "./HomePage.css";

interface Anniversary {
  id: number;
  title: string;
  start_date: string;
  days: number;
}

function HomePage() {
  const [anniversaries, setAnniversaries] = useState<Anniversary[]>([]);

  useEffect(() => {
    const loadAnniversaries = async () => {
      const result = await invoke<Anniversary[]>("get_anniversaries");
      setAnniversaries(result);
    };
    loadAnniversaries();
  }, []);
  // 获取导航函数
  const navigate = useNavigate();

  // 点击卡片时跳转到详情页
  const handleCardClick = (id: number) => {
    navigate(`/detail/${id}`); // 例如：/detail/1
  };

  return (
    <div className="container">
      <div className="header-bar">
        <h1>Count Down</h1>
        <button className="add-button" onClick={() => navigate("/add")}>
          <span className="plus-icon">+</span>
        </button>
      </div>

      <div className="anniversary-list">
        {anniversaries.map((item) => (
          <div
            key={item.id}
            className="anniversary-card"
            onClick={() => {
              handleCardClick(item.id);
            }}
          >
            <div className="anniversary-title">{item.title}</div>
            <div className="anniversary-info">
              <span className="days-count">{item.days}</span>
              <span className="start-date">{item.start_date}</span>
            </div>
          </div>
        ))}
      </div>
    </div>
  );
}

export default HomePage;
